"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@sentry/core");
var frontend_1 = require("./frontend");
var core_2 = require("@sentry/core");
exports.addBreadcrumb = core_2.addBreadcrumb;
exports.captureEvent = core_2.captureEvent;
exports.setUserContext = core_2.setUserContext;
var shim_1 = require("@sentry/shim");
exports.captureException = shim_1.captureException;
exports.captureMessage = shim_1.captureMessage;
exports.popScope = shim_1.popScope;
exports.pushScope = shim_1.pushScope;
exports.setExtraContext = shim_1.setExtraContext;
exports.setTagsContext = shim_1.setTagsContext;
/**
 * The Sentry Node SDK Client.
 *
 * To use this SDK, call the {@link Sdk.create} function as early as possible
 * in the main entry module. To set context information or send manual events,
 * use the provided methods.
 *
 * @example
 * const { SentryClient } = require('@sentry/node');
 *
 * SentryClient.create({
 *   dsn: '__DSN__',
 *   // ...
 * });
 *
 * @example
 * SentryClient.setContext({
 *   extra: { battery: 0.7 },
 *   tags: { user_mode: 'admin' },
 *   user: { id: '4711' },
 * });
 *
 * @example
 * SentryClient.addBreadcrumb({
 *   message: 'My Breadcrumb',
 *   // ...
 * });
 *
 * @example
 * SentryClient.captureMessage('Hello, world!');
 * SentryClient.captureException(new Error('Good bye'));
 * SentryClient.captureEvent({
 *   message: 'Manual',
 *   stacktrace: [
 *     // ...
 *   ],
 * });
 * TODO
 * @see NodeOptions for documentation on configuration options.
 */
function create(options) {
    core_1.createAndBind(frontend_1.NodeFrontend, options);
}
exports.create = create;
//# sourceMappingURL=sdk.js.map